//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithFuroChance](index.md)/[chi](chi.md)

# chi

[common]\
val [chi](chi.md): [Map](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)&lt;[Tatsu](../../mahjongutils.models/-tatsu/index.md), [ShantenWithGot](../-shanten-with-got/index.md)&gt;

每种搭子吃后的向听信息
